@@ -16,24 +16,25 @@ import pkg_resources
 
 
 try:
-    import builtins
+	import builtins
 except ImportError:
-    import __builtin__ as builtins
+	import __builtin__ as builtins
 else:
-    from importlib import reload
+	from importlib import reload
 
 realimport = builtins.__import__
 
 
-def no_c_library(name, globals=None, locals=None, fromlist=(), level=0):
-    if name == '__segments':  # refuse to load C segments library
-        raise ImportError
-    return realimport(
-        name,
-        globals=globals,
-        locals=locals,
-        fromlist=fromlist,
-        level=level)
+def no_c_library(name, globals = None, locals=None, fromlist = (), level = 0):
+	if name == '__segments':  # refuse to load C segments library
+		raise ImportError
+	return realimport(
+		name,
+		globals = globals,
+		locals = locals,
+		fromlist = fromlist,
+		level = level
+	)
 
 
 #
@@ -105,9 +106,13 @@ class test_infinity(unittest.TestCase):
 		self.assertGreater(a, 0)
 		self.assertEqual(a, a)
 
-	@unittest.skipIf(sys.version_info.major >= 3,
-		'Python 3 does not have cmp')
 	def test__cmp__(self):
+		try:
+			cmp()
+		except NameError:
+			# Python 3 does not have cmp() builtin
+			def cmp(a, b):
+				return (a > b) - (a < b)
 		a = segments.infinity()
 		self.assertEqual( 0, cmp(-a, -a))
 		self.assertEqual(-1, cmp(-a,  0))
@@ -246,14 +251,17 @@ class test_segment(unittest.TestCase):
 		self.assertEqual(False, [-1, 6] in segments.segment(0, 4))
 		self.assertEqual(True, 2 in segments.segment(0, 4))
 
-		# Paraphrasing the documentation for glue.segment.__contains__
-		# in ligo/segments.py: if a is a segment or a sequence of length two,
-		# then `a in b` tests if `b[0] <= a[0] <= a[1] <= b[1]`. Otherwise,
-		# `a in b` tests if `b[0] <= a <= b[1]`. The following four tests
-		# happen to work and return False in Python 2, but they raise
-		# a TypeError in Python 3 because Python does not permit comparisons
-		# of numbers with sequences. The exception message is
-		# "'<' not supported between instances of 'list' and 'int'".
+		# Paraphrasing the documentation for
+		# glue.segment.__contains__ in ligo/segments.py: if a is a
+		# segment or a sequence of length two, then `a in b` tests
+		# if `b[0] <= a[0] <= a[1] <= b[1]`. Otherwise, `a in b`
+		# tests if `b[0] <= a <= b[1]`. The following four tests
+		# happen to work and return False in Python 2, but they
+		# raise a TypeError in Python 3 because Python does not
+		# permit comparisons of numbers with sequences. The
+		# exception message is "'<' not supported between instances
+		# of 'list' and 'int'".
+
 		if sys.version_info.major <= 2:
 			self.assertEqual(False, [] in segments.segment(0, 4))
 			self.assertEqual(False, [0] in segments.segment(0, 4))
@@ -496,8 +504,14 @@ class test_segmentlist(unittest.TestCase):
 					raise AssertionError("%s did not raise TypeError" % expr)
 		self.assertEqual(eval("%s | %s" % (w, y)), segments.segmentlist([segments.segment(0, 30)]))
 
-
 class test_segmentlistdict(unittest.TestCase):
+	@staticmethod
+	def random_coalesced_segmentlistdict(n):
+		seglists = segments.segmentlistdict()
+		for key in map(chr, range(65, 65 + n)):
+			seglists[key] = verifyutils.random_coalesced_list(random.randint(1, algebra_listlength))
+		return seglists
+
 	def testextent_all(self):
 		a = segments.segmentlistdict({"H1": segments.segmentlist(), "L1": segments.segmentlist([segments.segment(25, 35)])})
 		self.assertEqual(a.extent_all(), segments.segment(25, 35))
@@ -529,6 +543,15 @@ class test_segmentlistdict(unittest.TestCase):
 		self.assertEqual(a, pickle.loads(pickle.dumps(a, protocol = 1)))
 		self.assertEqual(a, pickle.loads(pickle.dumps(a, protocol = 2)))
 
+	def testvote(self):
+		seglists = self.random_coalesced_segmentlistdict(15)
+		seglists.vote(seglists, 6)
+
+	def testintersection(self):
+		seglists = self.random_coalesced_segmentlistdict(15)
+		keys = ("A", "B", "C", "D")
+		seglists.intersection(keys)
+
 
 #
 # Construct and run the test suite.
@@ -544,6 +567,8 @@ if __name__ == "__main__":
 	finally:
 		# reinstate original import
 		builtins.__import__ = realimport
+
+	print("testing segments module located at %s" % segments.__file__)
 	verifyutils.segments = segments
 
 	suite = unittest.TestSuite()
@@ -562,6 +587,8 @@ if __name__ == "__main__":
 	# then with C extension implementation
 
 	reload(segments)  # loads C library and executes copyreg.pickle
+	print("testing segments module located at %s" % segments.__file__)
+
 	segments.infinity = segments.infinity
 	segments.NegInfinity = segments.NegInfinity
 	segments.PosInfinity = segments.PosInfinity
